function [C,m,z]=lead(F,om,option,M)
%
% function [C,m,z]=lead(F,om,option,M)
%
% Progetto di rete derivativa (lead)
%
% INPUT
% F: recupero di fase richiesto, in gradi
% om: pulsazione alla quale si richiede il recupero di fase (default=1)
% option: 1,2 o 3: tipologia di progetto (default=1)
%       1: recupero di fase in om/z=1 (recupero max=45, M=sqrt(2))
%       2: recupero di fase in om/z=sqrt(m) (recupero max=90, M=sqrt(m))
%       3: progetto tramite formule di inversione
% M: fattore di incremento di modulo in om (in unità lineari, non dB)
%       (utilizzato solo per la modalità di progetto option=3; default=sqrt(2))
%
% OUTPUT
% C: oggetto tf: C= (s/z+1)/(s/(m*z)+1)
% m: fattore m della rete
% z: valore assoluto dello zero della rete
%
% @ G. Calafiore, 2005
%
